//
//  SampleViewControllerStartStopTickingButtonSection.m
//  GroupedUITableViews
//
//  Created by Arseniy on 20/7/13.
//  Copyright (c) 2013 Arseniy Kuznetsov. All rights reserved.
//


#import "SampleViewControllerStartStopTickingButtonSection.h"

// defines rows in sections
enum  SampleViewControllerStartStopTickingButtonRows {
    kStartTickingtRow = 0,
    kSampleViewControllerStartStopTickingButtonNumRows
};

// Ticking states
typedef NS_ENUM (NSUInteger, TickingStates) {
    kTickingStatesNotStarted = 0,
    kTickingStatesTicking,
    kTickingStatesPaused
};

@implementation SampleViewControllerStartStopTickingButtonSection {
     TickingStates tickingState;
}

#pragma mark - Initialisation
- (void)initSpecifics {
    tickingState = kTickingStatesNotStarted;
}

#pragma mark - GroupedTableSectionsController Table View Data Source
- (NSUInteger)numberOfRows {
    return kSampleViewControllerStartStopTickingButtonNumRows;
}
- (UITableViewCell *)tableView:(UITableView *)tableView CellForRow:(NSUInteger)row {
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:self.defaultCellIdentifier];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault
                                                    reuseIdentifier:self.defaultCellIdentifier];
        cell.textLabel.font = [UIFont boldSystemFontOfSize:16];
        cell.textLabel.backgroundColor = [UIColor clearColor];
        cell.textLabel.textAlignment = NSTextAlignmentCenter;
        
        cell.backgroundView = [[UIImageView alloc] init];
        cell.selectedBackgroundView = [[UIImageView alloc] init];
        
        UIImage *buttonImage = [UIImage imageNamed:@"GenericButtonNormal_54.png"];
        UIImage *selectedButtonImage = [UIImage imageNamed:@"GenericButtonPushed_54.png"];
        
        ((UIImageView *)cell.backgroundView).image = buttonImage;
        ((UIImageView *)cell.selectedBackgroundView).image = selectedButtonImage;
    }
    return cell;
}
- (void)configureCell:(UITableViewCell *)cell ForRow:(NSUInteger)row {
    switch (tickingState) {
        case kTickingStatesNotStarted:
            cell.textLabel.text =  @"Start Ticking";
            break;
        case kTickingStatesTicking:
            cell.textLabel.text =  @"Pause Ticking";
            break;
        case kTickingStatesPaused:
            cell.textLabel.text =  @"Resume Ticking";            
            break;
        default:
            break;
    }
}

#pragma mark - GroupedTableSectionsController Table View Delegate
- (void)tableView:(UITableView *)tableView DidSelectRow:(NSInteger)row {
    switch (tickingState) {
        case kTickingStatesNotStarted:
        case kTickingStatesPaused:
            [[NSNotificationCenter defaultCenter] postNotificationName:START_TICKING_NOTIFICATION object:nil];
            tickingState = kTickingStatesTicking;
            break;
        case kTickingStatesTicking:
            [[NSNotificationCenter defaultCenter] postNotificationName:STOP_TICKING_NOTIFICATION object:nil];
            tickingState = kTickingStatesPaused;
            break;
        default:
            break;
    }
   [self performSelector:@selector(deselectRow) withObject:nil afterDelay:0.1f];
   [self performSelector:@selector(reloadSection) withObject:nil afterDelay:0.2f];
}
- (CGFloat)heightForRow:(NSInteger)row {
    return 54.0f;
}
- (CGFloat)heightForHeaderInSection {
    return 2.0f;
}
- (CGFloat)heightForFooterInSection {
    return 1.0f;
}


@end
