//
//  SampleViewControllerSuperPowersSection.m
//  GroupedUITableViews
//
//  Created by Arseniy on 19/7/13.
//  Copyright (c) 2013 Arseniy Kuznetsov. All rights reserved.
//

#import "SampleViewControllerSuperPowersSection.h"

@interface SampleViewControllerSuperPowersSection ()
    @property (nonatomic, assign) BOOL isTurnedOn;
    @property (nonatomic, strong) NSIndexPath *selectedIndexPath;
@end

// Defines rows in section
enum SuperPowersSectionRows {
    kSuperPowersSectionTurnOnOffRow = 0,
    kSuperPowersSectionShapeShiftingRow,
    kSuperPowersSectionPsychokinesisRow,
    kSuperPowersSectionTeleportationRow,
    kSuperPowersSectionRowsNumRows
};

@implementation SampleViewControllerSuperPowersSection

#pragma mark - Initialisation
- (void)initSpecifics {
    _isTurnedOn = NO;
    self.selectedIndexPath = [NSIndexPath
                              indexPathForRow:kSuperPowersSectionShapeShiftingRow inSection:self.sectionID];
}

#pragma mark - GroupedTableSectionsController Table View Data Source
- (NSUInteger)numberOfRows {
    return (_isTurnedOn) ? kSuperPowersSectionRowsNumRows : 1;
}
- (void)configureCell:(UITableViewCell *)cell ForRow:(NSUInteger)row {   
    cell.selectionStyle = UITableViewCellSelectionStyleNone;
    cell.textLabel.font = [UIFont systemFontOfSize:16];
    cell.backgroundColor = [UIColor clearColor];
    cell.accessoryView = nil;

    NSIndexPath *indexPath = [NSIndexPath indexPathForRow:row inSection:self.sectionID];
    if (self.selectedIndexPath && [self.selectedIndexPath compare:indexPath] == NSOrderedSame) {
        cell.accessoryType = UITableViewCellAccessoryCheckmark;
    } else {
        cell.accessoryType = UITableViewCellAccessoryNone;
    }
    switch (row) {
        case kSuperPowersSectionTurnOnOffRow:
        {
            cell.accessoryType = UITableViewCellAccessoryNone;
            cell.textLabel.font = [UIFont boldSystemFontOfSize:16];
            cell.textLabel.textAlignment = NSTextAlignmentLeft;
            
            UISwitch *superPowerSwitch = [[UISwitch alloc] initWithFrame:CGRectZero];
            [superPowerSwitch setOn:_isTurnedOn];
            [superPowerSwitch addTarget:self action:@selector(superPowerOptionChanged:)
                           forControlEvents:UIControlEventValueChanged];
            cell.textLabel.text = @"Super Power";
            cell.backgroundColor = [UIColor whiteColor];
            cell.accessoryView = superPowerSwitch;
            cell.detailTextLabel.text = @"";
            break;
        }
        case kSuperPowersSectionShapeShiftingRow:
        {
            cell.textLabel.text = @"Shape shifting";
            break;
        }
        case kSuperPowersSectionPsychokinesisRow:
        {
            cell.textLabel.text = @"Psychokinesis";
            break;
        }
        case kSuperPowersSectionTeleportationRow:
        {
            cell.textLabel.text = @"Teleportation";
            break;
        }
        default:
            break;
    }
}

#pragma mark - switch option change handler
- (void)superPowerOptionChanged:(id)sender {
    _isTurnedOn = [(UISwitch *)sender isOn];
    [self reloadSectionWithRowAnimation:UITableViewRowAnimationFade];
}

#pragma mark - GroupedTableSectionsController Table View Delegate
- (void)tableView:(UITableView *)tableView DidSelectRow:(NSInteger)row {
    if (row != kSuperPowersSectionTurnOnOffRow) {
        NSIndexPath *indexPath = [NSIndexPath indexPathForRow:row inSection:self.sectionID];
        if ([self.selectedIndexPath compare:indexPath] != NSOrderedSame) {
            NSArray *rowsArray = @[indexPath, self.selectedIndexPath];
            self.selectedIndexPath = indexPath;
            [tableView reloadRowsAtIndexPaths:rowsArray withRowAnimation:UITableViewRowAnimationFade];
        }
        [tableView deselectRowAtIndexPath:indexPath animated:YES];
    }
}
- (float)heightForRow:(NSInteger)row {
    return 40.0f;
}
- (NSString *)titleForHeaderInSection {
    return @"An expandable section";
}
- (CGFloat)heightForHeaderInSection {
    return 32.0f;
}
- (NSString *)titleForFooterInSection {
   NSString *footer = (_isTurnedOn) ?
                        @"With Power comes Responsibility" :
                        @"Unleashes the Power Within";
    return footer;
}
- (CGFloat)heightForFooterInSection {
    return 30.0f;
}

@end
