//
//  SampleViewControllerTickerSection.m
//  GroupedUITableViews
//
//  Created by Arseniy on 19/7/13.
//  Copyright (c) 2013 Arseniy Kuznetsov. All rights reserved.
//

#import "GroupedTableViewController.h"
#import "SampleViewControllerTickerSection.h"
#import "ShadowTextLabel.h"
#import "SampleViewControllerStartStopTickingButtonSection.h"

@interface SampleViewControllerTickerSection ()
    @property (nonatomic, retain) NSDate *start;
    @property (nonatomic, assign) NSTimeInterval durationInterval;
    @property (nonatomic, retain) ShadowTextLabel *counterLabel;
    @property (nonatomic, assign) BOOL isTicking;
@end

// Defines rows in section
enum SampleViewControllerTickerSectionRows {
    kSampleViewControllerTickerSectionStartRow = 0,
    kSampleViewControllerTickerSectionLabelRow,
    kSampleViewControllerTickerSectionNumRows
};

@implementation SampleViewControllerTickerSection

#pragma mark - Memory Management
- (void)dealloc {
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

#pragma mark - Initialisation
- (void)initSpecifics {
    _isTicking = NO;
    _durationInterval = 0.0f;
    self.counterLabel = [[ShadowTextLabel alloc] init];
    self.counterLabel.backgroundColor = [UIColor clearColor];

    [[NSNotificationCenter defaultCenter] addObserverForName:START_TICKING_NOTIFICATION
                                                      object:nil queue:nil usingBlock:^(NSNotification *note) {
          if (!self.start) {
              self.start = [NSDate date];
              [self reloadRow:kSampleViewControllerTickerSectionStartRow
                                    WithRowAnimation:UITableViewRowAnimationNone];
          }
          _isTicking = YES;
          [self updateCounterLabel];
    }];
    [[NSNotificationCenter defaultCenter] addObserverForName:STOP_TICKING_NOTIFICATION
                                                      object:nil queue:nil usingBlock:^(NSNotification *note) {
          _isTicking = NO;
    }];
    
}

#pragma mark - GroupedTableSectionsController Table View Data Source
- (NSUInteger)numberOfRows {
    return kSampleViewControllerTickerSectionNumRows;
}
- (UITableViewCell *)tableView:(UITableView *)tableView CellForRow:(NSUInteger)row {
    UITableViewCell *cell;
    switch (row) {
        case kSampleViewControllerTickerSectionStartRow:
            cell = [tableView dequeueReusableCellWithIdentifier:self.defaultCellIdentifier];
            if (cell == nil) {
                cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleValue1
                                              reuseIdentifier:self.defaultCellIdentifier];
            }
            cell.textLabel.textColor = [UIColor whiteColor];
            cell.textLabel.font = [UIFont boldSystemFontOfSize:14];
            cell.detailTextLabel.textColor = [UIColor whiteColor];
            cell.detailTextLabel.font = [UIFont boldSystemFontOfSize:14];
            cell.textLabel.textColor = [UIColor whiteColor];
            cell.textLabel.font = [UIFont boldSystemFontOfSize:14];
            
            cell.textLabel.text = @"Start Time";
            
            if (!self.start) {
                cell.detailTextLabel.text = @"Not Started";
            } else {
                NSDateFormatter *displayFormatter = [[NSDateFormatter alloc] init];
                [displayFormatter setDateFormat:@"hh:mm a"];
                cell.detailTextLabel.text = [NSString stringWithFormat:@"%@",
                                             [displayFormatter stringFromDate:self.start]];
            }
            break;            
        case kSampleViewControllerTickerSectionLabelRow:
        {
            static NSString *counterLabelCellID = @"counterLabelCellID";
            cell = [tableView dequeueReusableCellWithIdentifier:counterLabelCellID];
            if (cell == nil) {
                cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleValue1
                                              reuseIdentifier:counterLabelCellID];
                // add the label
                UILabel *theCounterLabel = self.counterLabel;
                theCounterLabel.text = @"00:00:00";
                theCounterLabel.translatesAutoresizingMaskIntoConstraints = NO;
                [cell.contentView addSubview:theCounterLabel];
                
                NSMutableArray *constraints = [NSMutableArray array];
                NSDictionary *labelViewDictionary = NSDictionaryOfVariableBindings(theCounterLabel);
                [constraints addObjectsFromArray:[NSLayoutConstraint constraintsWithVisualFormat:
                                                  @"|-[theCounterLabel]-|"
                                                                     options:0 metrics:nil
                                                                     views:labelViewDictionary]];
                [constraints addObjectsFromArray:[NSLayoutConstraint constraintsWithVisualFormat:
                                                  @"V:|-5-[theCounterLabel]-5-|"
                                                                     options:0 metrics:nil
                                                                     views:labelViewDictionary]];
                // Add the constraint against the contentView
                [cell.contentView addConstraints:constraints];
            }
            break;
        }
        default:
            break;
    }
    cell.selectionStyle = UITableViewCellSelectionStyleNone;
    cell.backgroundColor = [ShadowTextLabel UIColorFromRGB:(0x274249)];
    
    return cell;
}

#pragma mark - GroupedTableSectionsController Table View Delegate
- (NSString *)titleForHeaderInSection {
    return @"A composite section";
}
- (CGFloat)heightForHeaderInSection {
    return 30.0f;
}
- (CGFloat)heightForRow:(NSInteger)row {
    if (row == kSampleViewControllerTickerSectionStartRow) {
        return 24.0f;
    } else {
        return 60.0f;
    }
}
- (CGFloat)heightForFooterInSection {
    return 1;
}

#pragma mark - Counter Label ticking impl
- (void)updateCounterLabel {
    _durationInterval++;
    
    uint seconds = _durationInterval;
    uint minutes = seconds / 60;
    uint hours = minutes / 60;
    seconds -= minutes * 60;
    minutes -= hours * 60;
    
    self.counterLabel.text = [NSString stringWithFormat:@"%02u:%02u:%02u", hours, minutes, seconds];
    if (_isTicking) {
        [self performSelector:@selector(updateCounterLabel) withObject:nil afterDelay:1.0f];
    }
}


@end
